# This file was auto-generated by Fern from our API Definition.

import typing

from .eval_dataset_execution_config import EvalDatasetExecutionConfig
from .managed_data_source_ingestion_job_config import ManagedDataSourceIngestionJobConfig
from .managed_pipeline_ingestion_job_config import ManagedPipelineIngestionJobConfig
from .run_transform_asset_config import RunTransformAssetConfig

DataSourceManagedIngestionExecutionRunConfigPerOpValue = typing.Union[
    RunTransformAssetConfig,
    EvalDatasetExecutionConfig,
    ManagedPipelineIngestionJobConfig,
    ManagedDataSourceIngestionJobConfig,
]
